@@ -2,6 +2,7 @@ import os
 import ssl
 import shutil
 import socket
+import logging
 import collections
 
 from OpenSSL import crypto  # type: ignore
@@ -9,9 +10,10 @@ from OpenSSL import crypto  # type: ignore
 import synapse.exc as s_exc
 import synapse.common as s_common
 
+defdir_default = '~/.syn/certs'
 defdir = os.getenv('SYN_CERT_DIR')
 if defdir is None:
-    defdir = '~/.syn/certs'
+    defdir = defdir_default
 
 def iterFqdnUp(fqdn):
     levs = fqdn.split('.')
@@ -20,6 +22,8 @@ def iterFqdnUp(fqdn):
 
 TEN_YEARS = 10 * 365 * 24 * 60 * 60
 
+logger = logging.getLogger(__name__)
+
 class CertDir:
     '''
     Certificate loading/generation/signing utilities.
@@ -35,8 +39,8 @@ class CertDir:
         path (str): Optional path which can override the default path directory.
 
     Notes:
-        * All certificates will be loaded from and written to ~/.syn/certs by default. Set the envvar SYN_CERT_DIR to
-          override.
+        * All certificates will be loaded from and written to ~/.syn/certs by default. Set the environment variable
+          SYN_CERT_DIR to override.
         * All certificate generation methods create 4096 bit RSA keypairs.
         * All certificate signing methods use sha256 as the signature algorithm.
         * CertDir does not currently support signing CA CSRs.
@@ -116,7 +120,7 @@ class CertDir:
 
         return pkey, cert
 
-    def genHostCert(self, name, signas=None, outp=None, csr=None, sans=None):
+    def genHostCert(self, name, signas=None, outp=None, csr=None, sans=None, save=True):
         '''
         Generates a host keypair.
 
@@ -155,14 +159,15 @@ class CertDir:
         else:
             self.selfSignCert(cert, pkey)
 
-        if not pkey._only_public:
-            keypath = self._savePkeyTo(pkey, 'hosts', '%s.key' % name)
-            if outp is not None:
-                outp.printf('key saved: %s' % (keypath,))
+        if save:
+            if not pkey._only_public:
+                keypath = self._savePkeyTo(pkey, 'hosts', '%s.key' % name)
+                if outp is not None:
+                    outp.printf('key saved: %s' % (keypath,))
 
-        crtpath = self._saveCertTo(cert, 'hosts', '%s.crt' % name)
-        if outp is not None:
-            outp.printf('cert saved: %s' % (crtpath,))
+            crtpath = self._saveCertTo(cert, 'hosts', '%s.crt' % name)
+            if outp is not None:
+                outp.printf('cert saved: %s' % (crtpath,))
 
         return pkey, cert
 
@@ -184,7 +189,7 @@ class CertDir:
         '''
         return self._genPkeyCsr(name, 'hosts', outp=outp)
 
-    def genUserCert(self, name, signas=None, outp=None, csr=None):
+    def genUserCert(self, name, signas=None, outp=None, csr=None, save=True):
         '''
         Generates a user keypair.
 
@@ -216,14 +221,15 @@ class CertDir:
         else:
             self.selfSignCert(cert, pkey)
 
-        crtpath = self._saveCertTo(cert, 'users', '%s.crt' % name)
-        if outp is not None:
-            outp.printf('cert saved: %s' % (crtpath,))
-
-        if not pkey._only_public:
-            keypath = self._savePkeyTo(pkey, 'users', '%s.key' % name)
+        if save:
+            crtpath = self._saveCertTo(cert, 'users', '%s.crt' % name)
             if outp is not None:
-                outp.printf('key saved: %s' % (keypath,))
+                outp.printf('cert saved: %s' % (crtpath,))
+
+            if not pkey._only_public:
+                keypath = self._savePkeyTo(pkey, 'users', '%s.key' % name)
+                if outp is not None:
+                    outp.printf('key saved: %s' % (keypath,))
 
         return pkey, cert
 
@@ -680,7 +686,7 @@ class CertDir:
             None
         '''
         if not os.path.isfile(path):
-            raise s_exc.NoSuchFile(mesg='File does not exist', path=path)
+            raise s_exc.NoSuchFile(mesg=f'File {path} does not exist', path=path)
 
         fname = os.path.split(path)[1]
         parts = fname.rsplit('.', 1)
@@ -692,7 +698,7 @@ class CertDir:
 
         newpath = s_common.genpath(self.certdirs[0], mode, fname)
         if os.path.isfile(newpath):
-            raise s_exc.FileExists('File already exists')
+            raise s_exc.FileExists(mesg=f'File {newpath} already exists', path=path)
 
         shutil.copy(path, newpath)
         if outp is not None:
@@ -785,10 +791,10 @@ class CertDir:
         '''
         cakey = self.getCaKey(signas)
         if cakey is None:
-            raise s_exc.NoCertKey('Missing .key for %s' % signas)
+            raise s_exc.NoCertKey(mesg=f'Missing .key for {signas}')
         cacert = self.getCaCert(signas)
         if cacert is None:
-            raise s_exc.NoCertKey('Missing .crt for %s' % signas)
+            raise s_exc.NoCertKey(mesg=f'Missing .crt for {signas}')
 
         cert.set_issuer(cacert.get_subject())
         cert.sign(cakey, self.signing_digest)
@@ -973,7 +979,7 @@ class CertDir:
 
     def _checkDupFile(self, path):
         if os.path.isfile(path):
-            raise s_exc.DupFileName(path=path)
+            raise s_exc.DupFileName(mesg=f'Duplicate file {path}', path=path)
 
     def _genBasePkeyCert(self, name, pkey=None):
 
@@ -1096,7 +1102,13 @@ class CertDir:
         return path
 
 certdir = CertDir()
-def getCertDir():
+def getCertDir() -> CertDir:
+    '''
+    Get the singleton CertDir instance.
+
+    Returns:
+        CertDir: A certdir object.
+    '''
     return certdir
 
 def addCertPath(path):
@@ -1104,3 +1116,12 @@ def addCertPath(path):
 
 def delCertPath(path):
     return certdir.delCertPath(path)
+
+def getCertDirn() -> str:
+    '''
+    Get the expanded default path used by the singleton CertDir instance.
+
+    Returns:
+        str: The path string.
+    '''
+    return s_common.genpath(defdir)
