@@ -91,6 +91,11 @@ class LayerTest(s_t_utils.SynTest):
             errors = [e async for e in core.getLayer().verify()]
             self.len(2, errors)
 
+            core.getLayer()._testDelFormValuStor(buid, 'inet:ipv4')
+            errors = [e async for e in core.getLayer().verifyByProp('inet:ipv4', None)]
+            self.len(1, errors)
+            self.eq(errors[0][0], 'NoValuForPropIndex')
+
         async with self.getTestCore() as core:
 
             nodes = await core.nodes('[ inet:ipv4=1.2.3.4 :asn=20 +#foo.bar ]')
@@ -99,7 +104,7 @@ class LayerTest(s_t_utils.SynTest):
             core.getLayer()._testAddPropIndx(buid, 'inet:ipv4', 'asn', 30)
             errors = [e async for e in core.getLayer().verify()]
             self.len(1, errors)
-            self.eq(errors[0][0], 'SpurPropKeyForIndx')
+            self.eq(errors[0][0], 'SpurPropKeyForIndex')
 
         async with self.getTestCore() as core:
 
@@ -128,10 +133,103 @@ class LayerTest(s_t_utils.SynTest):
             layr.setSodeDirty(buid, sode, sode.get('form'))
 
             errors = [e async for e in core.getLayer().verify()]
-            self.len(3, errors)
+            self.len(2, errors)
             self.eq(errors[0][0], 'NoStorTypeForProp')
             self.eq(errors[1][0], 'NoStorTypeForProp')
-            self.eq(errors[2][0], 'SpurPropKeyForIndx')
+
+            sode['props'] = None
+            layr.setSodeDirty(buid, sode, sode.get('form'))
+            errors = [e async for e in core.getLayer().verify()]
+            self.len(4, errors)
+            for err in errors:
+                self.eq(err[0], 'NoValuForPropIndex')
+
+        # Check arrays
+        async with self.getTestCore() as core:
+
+            layr = core.getLayer()
+
+            nodes = await core.nodes('[ ps:contact=* :names=(foo, bar)]')
+            buid = nodes[0].buid
+
+            core.getLayer()._testAddPropArrayIndx(buid, 'ps:contact', 'names', ('baz',))
+
+            scanconf = {'autofix': 'index'}
+            errors = [e async for e in layr.verifyAllProps(scanconf=scanconf)]
+            self.len(1, errors)
+            self.eq(errors[0][0], 'SpurPropArrayKeyForIndex')
+
+            errors = [e async for e in layr.verifyAllProps()]
+            self.len(0, errors)
+
+            sode = await layr.getStorNode(buid)
+            names = sode['props']['names']
+            sode['props']['names'] = (names[0], 8675309)
+            layr.setSodeDirty(buid, sode, sode.get('form'))
+
+            scanconf = {'include': [('ps:contact', 'names')]}
+            errors = [e async for e in layr.verifyAllProps(scanconf=scanconf)]
+            self.len(3, errors)
+            self.eq(errors[0][0], 'NoStorTypeForProp')
+            self.eq(errors[1][0], 'NoStorTypeForPropArray')
+            self.eq(errors[2][0], 'NoStorTypeForPropArray')
+
+            sode = await layr.getStorNode(buid)
+            names = sode['props']['names']
+            sode['props'] = {}
+            layr.setSodeDirty(buid, sode, sode.get('form'))
+
+            errors = [e async for e in layr.verifyAllProps(scanconf=scanconf)]
+            self.len(3, errors)
+            self.eq(errors[0][0], 'NoValuForPropIndex')
+            self.eq(errors[1][0], 'NoValuForPropArrayIndex')
+            self.eq(errors[2][0], 'NoValuForPropArrayIndex')
+
+            sode['props'] = None
+            layr.setSodeDirty(buid, sode, sode.get('form'))
+            errors = [e async for e in core.getLayer().verify()]
+            self.len(5, errors)
+            self.eq(errors[0][0], 'NoValuForPropIndex')
+            self.eq(errors[1][0], 'NoValuForPropArrayIndex')
+            self.eq(errors[2][0], 'NoValuForPropArrayIndex')
+            self.eq(errors[3][0], 'NoValuForPropIndex')
+            self.eq(errors[4][0], 'NoValuForPropIndex')
+
+            await core.nodes('ps:contact | delnode --force')
+
+            core.getLayer()._testAddPropArrayIndx(buid, 'ps:contact', 'names', ('foo',))
+
+            errors = [e async for e in layr.verifyAllProps(scanconf=scanconf)]
+            self.len(3, errors)
+            self.eq(errors[0][0], 'NoNodeForPropIndex')
+            self.eq(errors[1][0], 'NoNodeForPropArrayIndex')
+            self.eq(errors[2][0], 'NoNodeForPropArrayIndex')
+
+            q = "$lib.model.ext.addForm('_test:array', array, ({'type': 'int'}), ({}))"
+            await core.nodes(q)
+            nodes = await core.nodes('[ _test:array=(1, 2, 3) ]')
+            buid = nodes[0].buid
+            core.getLayer()._testDelFormValuStor(buid, '_test:array')
+
+            scanconf = {'include': [('_test:array', None)]}
+            errors = [e async for e in layr.verifyAllProps(scanconf=scanconf)]
+            self.len(4, errors)
+            self.eq(errors[0][0], 'NoValuForPropIndex')
+            self.eq(errors[1][0], 'NoValuForPropArrayIndex')
+            self.eq(errors[2][0], 'NoValuForPropArrayIndex')
+            self.eq(errors[3][0], 'NoValuForPropArrayIndex')
+
+            scanconf = {'include': [('_test:array', None)], 'autofix': 'index'}
+            errors = [e async for e in layr.verifyAllProps(scanconf=scanconf)]
+            self.len(4, errors)
+            self.eq(errors[0][0], 'NoValuForPropIndex')
+            self.eq(errors[1][0], 'NoValuForPropArrayIndex')
+            self.eq(errors[2][0], 'NoValuForPropArrayIndex')
+            self.eq(errors[3][0], 'NoValuForPropArrayIndex')
+
+            scanconf = {'include': [('_test:array', None)]}
+            errors = [e async for e in layr.verifyAllProps(scanconf=scanconf)]
+            self.len(0, errors)
 
         # test autofix for tagindex verify
         async with self.getTestCore() as core:
@@ -167,6 +265,92 @@ class LayerTest(s_t_utils.SynTest):
             errors = [e async for e in core.getLayer().verify()]
             self.len(0, errors)
 
+        async with self.getTestCore() as core:
+            await core.addTagProp('score', ('int', {}), {})
+
+            layr = core.getLayer()
+            errors = [e async for e in layr.verifyAllBuids()]
+            self.len(0, errors)
+
+            errors = [e async for e in layr.verifyAllProps()]
+            self.len(0, errors)
+
+            errors = [e async for e in layr.verifyAllTagProps()]
+            self.len(0, errors)
+
+            layr._testAddTagPropIndx(buid, 'inet:ipv4', 'foo', 'score', 5)
+
+            scanconf = {'include': ['newp']}
+            errors = [e async for e in layr.verifyAllTagProps(scanconf=scanconf)]
+            self.len(0, errors)
+
+            errors = [e async for e in layr.verifyAllTagProps()]
+            self.len(2, errors)
+            self.eq(errors[0][0], 'NoNodeForTagPropIndex')
+            self.eq(errors[1][0], 'NoNodeForTagPropIndex')
+
+            nodes = await core.nodes('[ inet:ipv4=1.2.3.4 +#foo:score=5 ]')
+            buid = nodes[0].buid
+
+            layr._testAddTagPropIndx(buid, 'inet:ipv4', 'foo', 'score', 6)
+
+            scanconf = {'autofix': 'index'}
+            errors = [e async for e in layr.verifyAllTagProps(scanconf=scanconf)]
+            self.len(2, errors)
+            self.eq(errors[0][0], 'SpurTagPropKeyForIndex')
+            self.eq(errors[1][0], 'SpurTagPropKeyForIndex')
+
+            errors = [e async for e in layr.verifyAllTagProps()]
+            self.len(0, errors)
+
+            sode = await layr.getStorNode(buid)
+            score = sode['tagprops']['foo']['score']
+            sode['tagprops']['foo']['score'] = (score[0], 8675309)
+            layr.setSodeDirty(buid, sode, sode.get('form'))
+
+            errors = [e async for e in core.getLayer().verify()]
+            self.len(2, errors)
+            self.eq(errors[0][0], 'NoStorTypeForTagProp')
+            self.eq(errors[1][0], 'NoStorTypeForTagProp')
+
+            sode = await layr.getStorNode(buid)
+            sode['tagprops']['foo'] = {}
+            layr.setSodeDirty(buid, sode, sode.get('form'))
+
+            errors = [e async for e in core.getLayer().verify()]
+            self.len(2, errors)
+            self.eq(errors[0][0], 'NoValuForTagPropIndex')
+            self.eq(errors[1][0], 'NoValuForTagPropIndex')
+
+            sode = await layr.getStorNode(buid)
+            sode['tagprops'] = {}
+            layr.setSodeDirty(buid, sode, sode.get('form'))
+
+            errors = [e async for e in core.getLayer().verify()]
+            self.len(2, errors)
+            self.eq(errors[0][0], 'NoPropForTagPropIndex')
+            self.eq(errors[1][0], 'NoPropForTagPropIndex')
+
+            sode = await layr.getStorNode(buid)
+            sode['tagprops'] = None
+            layr.setSodeDirty(buid, sode, sode.get('form'))
+
+            errors = [e async for e in core.getLayer().verify()]
+            self.len(2, errors)
+            self.eq(errors[0][0], 'NoPropForTagPropIndex')
+            self.eq(errors[1][0], 'NoPropForTagPropIndex')
+
+            scanconf = {'autofix': 'newp'}
+
+            with self.raises(s_exc.BadArg):
+                errors = [e async for e in layr.verifyAllTags(scanconf=scanconf)]
+
+            with self.raises(s_exc.BadArg):
+                errors = [e async for e in layr.verifyAllProps(scanconf=scanconf)]
+
+            with self.raises(s_exc.BadArg):
+                errors = [e async for e in layr.verifyAllTagProps(scanconf=scanconf)]
+
     async def test_layer_abrv(self):
 
         async with self.getTestCore() as core:
@@ -444,6 +628,7 @@ class LayerTest(s_t_utils.SynTest):
 
     async def test_layer_splices(self):
 
+        self.skip('fragile order and deprecated')
         async with self.getTestCore() as core:
 
             layr = core.view.layers[0]
