@@ -193,6 +193,9 @@ eip-55 address test vectors
 0xdbF03B407c01E7cD3CBea99509d93f8DDDC8C6FB
 0xD1220A0cf47c7B9Be7A2E6BA89F429762e7b9aDb
 
+# Real world where someone upper() the whole string
+0X633B354CF215DFF4FF3D686AFF363FA0132877F3
+
 # Bad vectors!
 0x8617E340B3D01FA5F11F306F4090FD50E238070d
 0x27B1fdb04752bbc536007a920d24acb045561c26
@@ -384,7 +387,7 @@ class ScrapeTest(s_t_utils.SynTest):
         self.len(0, nodes)
 
         nodes = list(s_scrape.scrape(eth_addresses))
-        self.len(9, nodes)
+        self.len(10, nodes)
         nodes.remove(('crypto:currency:address',
                       ('eth', '0x001d3f1ef827552ae1114027bd3ecf1f086ba0f9')))
         nodes.remove(('crypto:currency:address',
@@ -403,6 +406,8 @@ class ScrapeTest(s_t_utils.SynTest):
                       ('eth', '0xdbF03B407c01E7cD3CBea99509d93f8DDDC8C6FB')))
         nodes.remove(('crypto:currency:address',
                       ('eth', '0xD1220A0cf47c7B9Be7A2E6BA89F429762e7b9aDb')))
+        nodes.remove(('crypto:currency:address',
+                      ('eth', '0x633b354cf215dff4ff3d686aff363fa0132877f3')))
         self.len(0, nodes)
 
         nodes = list(s_scrape.scrape(bch_addresses))
