@@ -337,18 +337,24 @@ class InetModelTest(s_t_utils.SynTest):
             'src:host': 32 * 'b',
             'src:proc': 32 * 'c',
             'src:exe': 64 * 'd',
+            'src:txcount': 30,
             'src:txbytes': 1,
             'src:handshake': 'Hello There',
             'dst': 'tcp://1.2.3.4:80',
             'dst:host': 32 * 'e',
             'dst:proc': 32 * 'f',
             'dst:exe': 64 * '0',
+            'dst:txcount': 33,
             'dst:txbytes': 2,
+            'tot:txcount': 63,
+            'tot:txbytes': 3,
             'dst:handshake': 'OHai!',
             'src:softnames': ('hehe', 'haha'),
             'dst:softnames': ('foobar', 'bazfaz'),
             'src:cpes': ('cpe:2.3:a:zzz:yyy:*:*:*:*:*:*:*:*', 'cpe:2.3:a:aaa:bbb:*:*:*:*:*:*:*:*'),
             'dst:cpes': ('cpe:2.3:a:zzz:yyy:*:*:*:*:*:*:*:*', 'cpe:2.3:a:aaa:bbb:*:*:*:*:*:*:*:*'),
+            'ip:proto': 6,
+            'ip:tcp:flags': 0x20,
         }
         expected_props = {
             'time': 0,
@@ -361,6 +367,7 @@ class InetModelTest(s_t_utils.SynTest):
             'src:host': 32 * 'b',
             'src:proc': 32 * 'c',
             'src:exe': 'sha256:' + 64 * 'd',
+            'src:txcount': 30,
             'src:txbytes': 1,
             'src:handshake': 'Hello There',
             'dst': 'tcp://1.2.3.4:80',
@@ -370,12 +377,17 @@ class InetModelTest(s_t_utils.SynTest):
             'dst:host': 32 * 'e',
             'dst:proc': 32 * 'f',
             'dst:exe': 'sha256:' + 64 * '0',
+            'dst:txcount': 33,
             'dst:txbytes': 2,
+            'tot:txcount': 63,
+            'tot:txbytes': 3,
             'dst:handshake': 'OHai!',
             'src:softnames': ('haha', 'hehe'),
             'dst:softnames': ('bazfaz', 'foobar'),
             'src:cpes': ('cpe:2.3:a:aaa:bbb:*:*:*:*:*:*:*:*', 'cpe:2.3:a:zzz:yyy:*:*:*:*:*:*:*:*'),
             'dst:cpes': ('cpe:2.3:a:aaa:bbb:*:*:*:*:*:*:*:*', 'cpe:2.3:a:zzz:yyy:*:*:*:*:*:*:*:*'),
+            'ip:proto': 6,
+            'ip:tcp:flags': 0x20,
         }
         expected_ndef = (formname, 32 * 'a')
         async with self.getTestCore() as core:
@@ -1427,7 +1439,10 @@ class InetModelTest(s_t_utils.SynTest):
                               'site': 'vertex.link',
                               'site:host': 'vertex',
                               'site:domain': 'link', },
-                     'adds': []}
+                     'adds': (
+                        ('inet:fqdn', 'vertex.link', {'subs': {'domain': 'link', 'host': 'vertex'}}),
+                        ('inet:user', 'person1', {}),
+                    )}
             self.eq(t.norm(('VerTex.linK', 'PerSon1')), (enorm, edata))
 
             # Form Tests
